@@ -8,6 +8,7 @@ documentation for details on how to use these functions and classes.
 import objc as _objc
 #import ATS
 from CoreFoundation import *
+import Foundation
 from Quartz import *
 
 __bundle__ = _objc.initFrameworkWrapper("CoreText",
@@ -16,4 +17,4 @@ __bundle__ = _objc.initFrameworkWrapper("CoreText",
         "/System/Library/Frameworks/ApplicationServices.framework/Frameworks/CoreText.framework"),
     globals=globals())
 
-from _manual import *
+from CoreText._manual import *
