@@ -5,20 +5,20 @@ from CoreText import *
 class TestCTFramesetter (TestCase):
 
     def testTypes(self):
-        self.failUnlessIsInstance(CTFramesetterRef, objc.objc_class)
+        self.assertIsInstance(CTFramesetterRef, objc.objc_class)
 
     def testFunctions(self):
         v = CTFramesetterGetTypeID()
-        self.failUnlessIsInstance(v, (int, long))
+        self.assertIsInstance(v, (int, long))
 
         setter = CTFramesetterCreateWithAttributedString(
                     CFAttributedStringCreate(None, u"hello", None))
-        self.failUnlessIsInstance(setter, CTFramesetterRef)
+        self.assertIsInstance(setter, CTFramesetterRef)
 
         # CTFramesetterCreateFrame: tested in test_ctframe.py
 
         v = CTFramesetterGetTypesetter(setter)
-        self.failUnlessIsInstance(v, CTTypesetterRef)
+        self.assertIsInstance(v, CTTypesetterRef)
 
     @min_os_level('10.5')
     def testMethods10_5(self):
